from ..types.device_data import DeviceDataT
GOOGLE_DEIVCES_LIST: list[DeviceDataT] = [
    {
        "model_name": "Pixel 9 Pro Fold",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "comet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro Fold",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030.A1",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "comet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro Fold",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.047",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "comet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro Fold",
        "android_version": "14.0.0",
        "build_id": "AD1A.240905.004",
        "patch_date": "2024-09-05",
        "model_firmware_codename": "comet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro Fold",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "comet",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro Fold",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "comet",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "caiman",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030.A1",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "caiman",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030.A2",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "caiman",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.047",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "caiman",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro",
        "android_version": "14.0.0",
        "build_id": "AD1A.240905.004",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "caiman",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "caiman",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "caiman",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro XL",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "komodo",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro XL",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030.A1",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "komodo",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro XL",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030.A2",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "komodo",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro XL",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.047",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "komodo",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro XL",
        "android_version": "14.0.0",
        "build_id": "AD1A.240905.004",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "komodo",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro XL",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "komodo",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9 Pro XL",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "komodo",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "tokay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030.A1",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "tokay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030.A2",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "tokay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.030.B1",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "tokay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9",
        "android_version": "14.0.0",
        "build_id": "AD1A.240530.047",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "tokay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9",
        "android_version": "14.0.0",
        "build_id": "AD1A.240905.004",
        "patch_date": "2024-09-05",
        "model_firmware_codename": "tokay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "tokay",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 9",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "tokay",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "UD2A.231203.054",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "UD2A.231203.057",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "UD2A.231203.057.A1",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "UD2A.240505.001",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "UD2A.240505.001.A1",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "UD2A.240505.001.B1",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "UD2A.240505.001.D1",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "UD2A.240505.001.W1",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024.A1",
        "patch_date": "2024-06-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.005",
        "patch_date": "2024-07-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.005.A1",
        "patch_date": "2024-07-05",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005.A1",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005.C1",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005.E1",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003.A1",
        "patch_date": "2024-09-05",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003.C1",
        "patch_date": "2024-09-05",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003.E1",
        "patch_date": "2024-09-05",
        "model_firmware_codename": "akita",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "akita",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8a",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "akita",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UD1A.230803.022",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UD1A.230803.022.A3",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UD1A.230803.022.A4",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UD1A.230803.022.B1",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UD1A.230803.041",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UD1A.231105.004",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015",
        "patch_date": "2023-12-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015.A1",
        "patch_date": "2023-12-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004.A1",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.004",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.004.A1",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.004.B1",
        "patch_date": "2024-02-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002",
        "patch_date": "2024-04-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002.B1",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.A1",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.B1",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024.A1",
        "patch_date": "2024-06-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.005",
        "patch_date": "2024-07-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.005.A1",
        "patch_date": "2024-07-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005.B1",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005.D1",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003.B1",
        "patch_date": "2024-09-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003.D1",
        "patch_date": "2024-09-05",
        "model_firmware_codename": "husky",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "husky",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8 Pro",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "husky",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UD1A.230803.022.A5",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UD1A.230803.022.B2",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UD1A.230803.022.C1",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UD1A.230803.022.D1",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UD1A.230803.041",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UD1A.231105.004",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015",
        "patch_date": "2023-12-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015.A1",
        "patch_date": "2023-12-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004",
        "patch_date": "2024-01-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004.A1",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.004",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.004.A1",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.004.B1",
        "patch_date": "2024-02-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002",
        "patch_date": "2024-04-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002.B1",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.A1",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.B1",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024.A1",
        "patch_date": "2024-06-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.005",
        "patch_date": "2024-07-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.005.A1",
        "patch_date": "2024-07-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005.B1",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005.D1",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003.B1",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003.D1",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "shiba",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "shiba",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 8",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "shiba",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TD3A.230203.070.A1",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230605.010.C1",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230605.010.C2",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230605.010.D1",
        "patch_date": "2023-06-01",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230705.001.B1",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230705.001.C1",
        "patch_date": "2023-07-01",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230705.001.C2",
        "patch_date": "2023-07-01",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230805.001.A3",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230805.001.A4",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230805.001.B2",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230901.001.A1",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230901.001.A2",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "13.0.0",
        "build_id": "TQ3C.230901.001.B1",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "felix",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007.A1",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003",
        "patch_date": "2023-11-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003.A1",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015",
        "patch_date": "2023-12-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015.A1",
        "patch_date": "2023-12-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004",
        "patch_date": "2024-01-01",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004.A1",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002.A1",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002.B1",
        "patch_date": "2024-02-01",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002.A1",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002.A2",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.A1",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.B1",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.004",
        "patch_date": "2024-07-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "felix",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "felix",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Fold",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "felix",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "13.0.0",
        "build_id": "TD2A.230203.028",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "tangorpro",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.009.A1",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "tangorpro",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001.B4",
        "patch_date": "2023-07-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.B1",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.B1",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003",
        "patch_date": "2023-11-05",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015",
        "patch_date": "2023-12-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.002",
        "patch_date": "2024-01-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002",
        "patch_date": "2024-02-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002",
        "patch_date": "2024-04-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-05",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.004",
        "patch_date": "2024-07-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel Tablet",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "tangorpro",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TD4A.221205.042",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TD4A.221205.042.A1",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TD4A.221205.042.B1",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TQ2B.230505.005.A1",
        "patch_date": "2023-05-01",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.012",
        "patch_date": "2023-06-01",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.012.A1",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001",
        "patch_date": "2023-07-01",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001.A1",
        "patch_date": "2023-07-01",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A3",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C3",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "lynx",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007.A1",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003",
        "patch_date": "2023-11-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003.A1",
        "patch_date": "2023-11-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015",
        "patch_date": "2023-12-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015.A1",
        "patch_date": "2023-12-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004",
        "patch_date": "2024-01-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004.A1",
        "patch_date": "2024-01-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002",
        "patch_date": "2024-02-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002.A1",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002.B1",
        "patch_date": "2024-02-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002.B1",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.A1",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.B1",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.004",
        "patch_date": "2024-07-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "lynx",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "lynx",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7a",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "lynx",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TD1A.220804.009.A2",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TD1A.220804.009.A5",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TD1A.220804.031",
        "patch_date": "2022-10-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TD1A.221105.001",
        "patch_date": "2022-11-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TD1A.221105.003",
        "patch_date": "2022-11-01",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TD1A.221105.001.A1",
        "patch_date": "2022-11-01",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.011",
        "patch_date": "2022-12-01",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.012",
        "patch_date": "2022-12-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.002",
        "patch_date": "2023-01-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.002.A1",
        "patch_date": "2023-01-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.A2",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.D2",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.002",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.A3",
        "patch_date": "2023-03-01",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.C1",
        "patch_date": "2023-03-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.E1",
        "patch_date": "2023-04-01",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.012",
        "patch_date": "2023-06-01",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.012.A1",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001.A1",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A2",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C2",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "cheetah",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-01",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007.A1",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003.A1",
        "patch_date": "2023-11-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015",
        "patch_date": "2023-12-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015.A1",
        "patch_date": "2023-12-01",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004.A1",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002.A1",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002.B1",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002",
        "patch_date": "2024-04-01",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002.B1",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.A1",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.B1",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.004",
        "patch_date": "2024-07-01",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "cheetah",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "cheetah",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7 Pro",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "cheetah",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TD1A.220804.009.A2",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TD1A.220804.009.A5",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TD1A.220804.031",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TD1A.221105.001",
        "patch_date": "2022-11-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TD1A.221105.003",
        "patch_date": "2022-11-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TD1A.221105.001.A1",
        "patch_date": "2022-11-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.011",
        "patch_date": "2022-12-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.012",
        "patch_date": "2022-12-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.001.A2",
        "patch_date": "2023-01-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.001.A3",
        "patch_date": "2023-01-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.A2",
        "patch_date": "2023-02-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.D2",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.002",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008",
        "patch_date": "2023-03-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.A1",
        "patch_date": "2023-03-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.E1",
        "patch_date": "2023-04-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002",
        "patch_date": "2023-05-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.012",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.012.A1",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001",
        "patch_date": "2023-07-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001.A1",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A2",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C2",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "panther",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-01",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007.A1",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003.A1",
        "patch_date": "2023-11-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015",
        "patch_date": "2023-12-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015.A1",
        "patch_date": "2023-12-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.004.A1",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002.A1",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002.B1",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002",
        "patch_date": "2024-04-01",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002.B1",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.A1",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.005.B1",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-01",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.004",
        "patch_date": "2024-07-01",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "panther",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "panther",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 7",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "panther",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "12.1.0",
        "build_id": "SD2A.220601.001.A1",
        "patch_date": "2022-06-05",
        "model_firmware_codename": "bluejay",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "12.1.0",
        "build_id": "SD2A.220601.004",
        "patch_date": "2022-06-05",
        "model_firmware_codename": "bluejay",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "12.1.0",
        "build_id": "SD2A.220601.002",
        "patch_date": "2022-06-05",
        "model_firmware_codename": "bluejay",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "12.1.0",
        "build_id": "SD2A.220601.003",
        "patch_date": "2022-06-05",
        "model_firmware_codename": "bluejay",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "12.1.0",
        "build_id": "SD2A.220601.002.B1",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "bluejay",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "12.1.0",
        "build_id": "SD2A.220601.001.B1",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "bluejay",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "12.1.0",
        "build_id": "SD2A.220601.003.B1",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "bluejay",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "12.1.0",
        "build_id": "SD2A.220601.004.B2",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "bluejay",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TP1A.220624.021.A1",
        "patch_date": "2022-08-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004.A2",
        "patch_date": "2022-09-05",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.003",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TP1A.221105.002",
        "patch_date": "2022-11-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.011",
        "patch_date": "2022-12-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.012",
        "patch_date": "2022-12-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.001.A2",
        "patch_date": "2023-01-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.D2",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.002",
        "patch_date": "2023-02-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.E1",
        "patch_date": "2023-03-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.F1",
        "patch_date": "2023-03-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.E1",
        "patch_date": "2023-04-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002.G1",
        "patch_date": "2023-05-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.010",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.010.A1",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001.A1",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A1",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A2",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C1",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C2",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "bluejay",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007.A1",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003.A1",
        "patch_date": "2023-11-05",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015",
        "patch_date": "2023-12-01",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.002",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002",
        "patch_date": "2024-02-01",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-01",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-05",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.004",
        "patch_date": "2024-07-05",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005.F1",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003.F1",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "bluejay",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "bluejay",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6a",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "bluejay",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.015.A4",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.019.B1",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.019.C2",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.019.C4",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.036",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.036.A8",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.037",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.037.A1",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SQ1D.220105.007",
        "patch_date": "2022-01-01",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SQ1D.220205.003",
        "patch_date": "2022-02-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.0.0",
        "build_id": "SQ1D.220205.004",
        "patch_date": "2022-02-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SP2A.220305.013.A3",
        "patch_date": "2022-03-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SP2A.220405.004",
        "patch_date": "2022-04-01",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.002",
        "patch_date": "2022-05-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220605.009.A1",
        "patch_date": "2022-06-01",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220605.009.B1",
        "patch_date": "2022-06-01",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.001.B1",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003.A1",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003.A3",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.004.A1",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.004",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.001.B2",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "oriole",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TP1A.220624.021",
        "patch_date": "2022-08-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004",
        "patch_date": "2022-09-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004.A1",
        "patch_date": "2022-09-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.002",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TP1A.221105.002",
        "patch_date": "2022-11-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.011",
        "patch_date": "2022-12-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.002",
        "patch_date": "2023-01-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.D2",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.002",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.E1",
        "patch_date": "2023-03-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.F1",
        "patch_date": "2023-03-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.E1",
        "patch_date": "2023-04-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002.G1",
        "patch_date": "2023-05-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.010",
        "patch_date": "2023-06-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.010.A1",
        "patch_date": "2023-06-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001.A1",
        "patch_date": "2023-07-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A1",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A2",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C1",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C2",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "oriole",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007.A1",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003",
        "patch_date": "2023-11-05",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003.A1",
        "patch_date": "2023-11-05",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015",
        "patch_date": "2023-12-01",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.002",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-01",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002",
        "patch_date": "2024-04-01",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-05",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-05",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.004",
        "patch_date": "2024-07-01",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005.F1",
        "patch_date": "2024-08-01",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003.F1",
        "patch_date": "2024-09-01",
        "model_firmware_codename": "oriole",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "oriole",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-05",
        "model_firmware_codename": "oriole",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.015.A4",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.019.B1",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.019.C2",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.019.C4",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.036",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.036.A8",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.037",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SD1A.210817.037.A1",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SQ1D.220105.007",
        "patch_date": "2022-01-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SQ1D.220205.003",
        "patch_date": "2022-02-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.0.0",
        "build_id": "SQ1D.220205.004",
        "patch_date": "2022-02-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SP2A.220305.013.A3",
        "patch_date": "2022-03-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SP2A.220405.004",
        "patch_date": "2022-04-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.002",
        "patch_date": "2022-05-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220605.009.A1",
        "patch_date": "2022-06-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220605.009.B1",
        "patch_date": "2022-06-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.001.B1",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003.A1",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003.A3",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.004.A1",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.004",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.001.B2",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "raven",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TP1A.220624.021",
        "patch_date": "2022-08-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004",
        "patch_date": "2022-09-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004.A1",
        "patch_date": "2022-09-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.002",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TP1A.221105.002",
        "patch_date": "2022-11-01",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.011",
        "patch_date": "2022-12-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.002",
        "patch_date": "2023-01-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.D2",
        "patch_date": "2023-02-01",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.002",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.E1",
        "patch_date": "2023-03-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.F1",
        "patch_date": "2023-03-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.E1",
        "patch_date": "2023-04-01",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002.G1",
        "patch_date": "2023-05-01",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.010",
        "patch_date": "2023-06-01",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.010.A1",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001",
        "patch_date": "2023-07-01",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001.A1",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A1",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A2",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C1",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C2",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "raven",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007.A1",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.003.A1",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.015",
        "patch_date": "2023-12-01",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.002",
        "patch_date": "2024-01-05",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-01",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-05",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.004",
        "patch_date": "2024-07-01",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005.F1",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "14.0.0",
        "build_id": "AP2A.240905.003.F1",
        "patch_date": "2024-09-05",
        "model_firmware_codename": "raven",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "raven",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 6 Pro",
        "android_version": "15.0.0",
        "build_id": "AP3A.241005.015.A2",
        "patch_date": "2024-10-01",
        "model_firmware_codename": "raven",
        "api_level": "35",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "11.0.0",
        "build_id": "RD2A.210605.006",
        "patch_date": "2021-06-01",
        "model_firmware_codename": "barbet",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "11.0.0",
        "build_id": "RD2A.210605.007",
        "patch_date": "2021-06-05",
        "model_firmware_codename": "barbet",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "11.0.0",
        "build_id": "RD2A.210905.002",
        "patch_date": "2021-09-05",
        "model_firmware_codename": "barbet",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "11.0.0",
        "build_id": "RD2A.210905.003",
        "patch_date": "2021-09-01",
        "model_firmware_codename": "barbet",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "11.0.0",
        "build_id": "RD2A.211001.001",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "barbet",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "11.0.0",
        "build_id": "RD2A.211001.002",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "barbet",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.015",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A1",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002.A1",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.003",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.0.0",
        "build_id": "SQ1A.211205.008",
        "patch_date": "2021-12-05",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220105.002",
        "patch_date": "2022-01-05",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220205.002",
        "patch_date": "2022-02-05",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220305.012",
        "patch_date": "2022-03-05",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220405.003",
        "patch_date": "2022-04-01",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.002",
        "patch_date": "2022-05-05",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220605.009.A1",
        "patch_date": "2022-06-01",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003.A1",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "barbet",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TP1A.220624.014",
        "patch_date": "2022-08-05",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004",
        "patch_date": "2022-09-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.002",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TP1A.221105.002",
        "patch_date": "2022-11-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.011",
        "patch_date": "2022-12-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.001",
        "patch_date": "2023-01-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.D2",
        "patch_date": "2023-02-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.002",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.A3",
        "patch_date": "2023-03-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.C1",
        "patch_date": "2023-03-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003",
        "patch_date": "2023-04-05",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.A2",
        "patch_date": "2023-04-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.B2",
        "patch_date": "2023-04-05",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002.A1",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.011",
        "patch_date": "2023-06-05",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A2",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C2",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "barbet",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.001",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.231205.014",
        "patch_date": "2023-12-01",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240105.002",
        "patch_date": "2024-01-01",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "UQ1A.240205.002",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240305.019.A1",
        "patch_date": "2024-03-05",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240405.002",
        "patch_date": "2024-04-05",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "AP1A.240505.004",
        "patch_date": "2024-05-01",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240605.024",
        "patch_date": "2024-06-05",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240705.004",
        "patch_date": "2024-07-05",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5a",
        "android_version": "14.0.0",
        "build_id": "AP2A.240805.005",
        "patch_date": "2024-08-05",
        "model_firmware_codename": "barbet",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RD1A.200810.020",
        "patch_date": "2020-10-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RD1A.200810.020.A1",
        "patch_date": "2020-10-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RD1A.200810.021.A1",
        "patch_date": "2020-10-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RD1A.200810.021.B3",
        "patch_date": "2020-10-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RD1A.200810.022.A4",
        "patch_date": "2020-10-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RD1A.201105.003",
        "patch_date": "2020-11-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RD1A.201105.003.A1",
        "patch_date": "2020-11-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RD1A.201105.003.B1",
        "patch_date": "2020-11-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RD1A.201105.003.C1",
        "patch_date": "2020-11-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RD1B.201105.010",
        "patch_date": "2020-11-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.010",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.011",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ1D.201205.012.A1",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210105.003",
        "patch_date": "2021-01-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ1D.210105.003",
        "patch_date": "2021-01-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210205.004",
        "patch_date": "2021-02-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ1C.210205.006",
        "patch_date": "2021-02-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ1D.210205.004",
        "patch_date": "2021-02-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.006",
        "patch_date": "2021-03-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.007",
        "patch_date": "2021-03-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.005",
        "patch_date": "2021-04-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210505.003",
        "patch_date": "2021-05-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210605.005",
        "patch_date": "2021-06-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210705.001",
        "patch_date": "2021-07-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210805.001.A1",
        "patch_date": "2021-08-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210905.001",
        "patch_date": "2021-09-05",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "11.0.0",
        "build_id": "RQ3A.211001.001",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "redfin",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.015",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A1",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002.A1",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.003",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.004",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.0.0",
        "build_id": "SQ1A.211205.008",
        "patch_date": "2021-12-01",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220105.002",
        "patch_date": "2022-01-01",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220205.002",
        "patch_date": "2022-02-01",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.1.0",
        "build_id": "SP2A.220305.012",
        "patch_date": "2022-03-05",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.1.0",
        "build_id": "SP2A.220405.003",
        "patch_date": "2022-04-01",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.002",
        "patch_date": "2022-05-01",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220605.009.A1",
        "patch_date": "2022-06-01",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003.A1",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "redfin",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TP1A.220624.014",
        "patch_date": "2022-08-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004",
        "patch_date": "2022-09-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.002",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TP1A.221105.002",
        "patch_date": "2022-11-01",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.011",
        "patch_date": "2022-12-01",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.001",
        "patch_date": "2023-01-01",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.D2",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.002",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.A3",
        "patch_date": "2023-03-01",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.C1",
        "patch_date": "2023-03-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003",
        "patch_date": "2023-04-01",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.A2",
        "patch_date": "2023-04-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.B2",
        "patch_date": "2023-04-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002.A1",
        "patch_date": "2023-05-01",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.011",
        "patch_date": "2023-06-01",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A2",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C2",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "redfin",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-01",
        "model_firmware_codename": "redfin",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.001",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "redfin",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 5",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.001.B2",
        "patch_date": "2024-02-01",
        "model_firmware_codename": "redfin",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RD1A.200810.020",
        "patch_date": "2020-10-01",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RD1A.200810.021.A1",
        "patch_date": "2020-10-01",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RD1A.200810.021.B3",
        "patch_date": "2020-10-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RD1A.200810.022.A4",
        "patch_date": "2020-10-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RD1A.201105.003",
        "patch_date": "2020-11-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RD1A.201105.003.A1",
        "patch_date": "2020-11-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RD1A.201105.003.B1",
        "patch_date": "2020-11-01",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RD1A.201105.003.C1",
        "patch_date": "2020-11-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RD1B.201105.010",
        "patch_date": "2020-11-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.010",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.011",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ1D.201205.012.A1",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210105.003",
        "patch_date": "2021-01-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ1D.210105.003",
        "patch_date": "2021-01-01",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210205.004",
        "patch_date": "2021-02-01",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ1C.210205.006",
        "patch_date": "2021-02-01",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ1D.210205.004",
        "patch_date": "2021-02-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.006",
        "patch_date": "2021-03-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.007",
        "patch_date": "2021-03-01",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.005",
        "patch_date": "2021-04-01",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210505.003",
        "patch_date": "2021-05-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210605.005",
        "patch_date": "2021-06-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210705.001",
        "patch_date": "2021-07-01",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210805.001.A1",
        "patch_date": "2021-08-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210905.001",
        "patch_date": "2021-09-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "11.0.0",
        "build_id": "RQ3A.211001.001",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "bramble",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.015",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A1",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002.A1",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.003",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.004",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.0.0",
        "build_id": "SQ1A.211205.008",
        "patch_date": "2021-12-05",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220105.002",
        "patch_date": "2022-01-05",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220205.002",
        "patch_date": "2022-02-01",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.1.0",
        "build_id": "SP2A.220305.012",
        "patch_date": "2022-03-01",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.1.0",
        "build_id": "SP2A.220405.003",
        "patch_date": "2022-04-01",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.002",
        "patch_date": "2022-05-05",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220605.009.A1",
        "patch_date": "2022-06-05",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003.A1",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "bramble",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TP1A.220624.014",
        "patch_date": "2022-08-05",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004",
        "patch_date": "2022-09-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.002",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TP1A.221105.002",
        "patch_date": "2022-11-05",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.011",
        "patch_date": "2022-12-05",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.001",
        "patch_date": "2023-01-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.D2",
        "patch_date": "2023-02-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.002",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.A3",
        "patch_date": "2023-03-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.C1",
        "patch_date": "2023-03-05",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003",
        "patch_date": "2023-04-05",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.A2",
        "patch_date": "2023-04-05",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.B2",
        "patch_date": "2023-04-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002",
        "patch_date": "2023-05-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002.A1",
        "patch_date": "2023-05-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.011",
        "patch_date": "2023-06-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001",
        "patch_date": "2023-07-05",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A2",
        "patch_date": "2023-08-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001",
        "patch_date": "2023-09-01",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230901.001.C2",
        "patch_date": "2023-09-05",
        "model_firmware_codename": "bramble",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "14.0.0",
        "build_id": "UP1A.231005.007",
        "patch_date": "2023-10-05",
        "model_firmware_codename": "bramble",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.001",
        "patch_date": "2023-11-05",
        "model_firmware_codename": "bramble",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a (5G)",
        "android_version": "14.0.0",
        "build_id": "UP1A.231105.001.B2",
        "patch_date": "2024-02-05",
        "model_firmware_codename": "bramble",
        "api_level": "34",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "10.0.0",
        "build_id": "QD4A.200317.024.A1",
        "patch_date": "2020-05-01",
        "model_firmware_codename": "sunfish",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "10.0.0",
        "build_id": "QD4A.200317.027",
        "patch_date": "2020-08-01",
        "model_firmware_codename": "sunfish",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "10.0.0",
        "build_id": "QD4A.200805.001",
        "patch_date": "2020-08-01",
        "model_firmware_codename": "sunfish",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "10.0.0",
        "build_id": "QD4A.200805.003",
        "patch_date": "2020-08-01",
        "model_firmware_codename": "sunfish",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RP1A.200720.010",
        "patch_date": "2020-09-05",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RP1A.200720.011",
        "patch_date": "2020-09-05",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.006",
        "patch_date": "2020-10-01",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RP1A.201105.002",
        "patch_date": "2020-11-05",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.008",
        "patch_date": "2020-12-01",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210105.002",
        "patch_date": "2021-01-01",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210205.004",
        "patch_date": "2021-02-01",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.006",
        "patch_date": "2021-03-01",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.007",
        "patch_date": "2021-03-05",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.005",
        "patch_date": "2021-04-01",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210505.002",
        "patch_date": "2021-05-01",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210605.005",
        "patch_date": "2021-06-01",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210705.001",
        "patch_date": "2021-07-01",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210805.001.A1",
        "patch_date": "2021-08-05",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210905.001",
        "patch_date": "2021-09-05",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "11.0.0",
        "build_id": "RQ3A.211001.001",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "sunfish",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.015",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A1",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002.A1",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.004",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.0.0",
        "build_id": "SQ1A.211205.008",
        "patch_date": "2021-12-05",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220105.002",
        "patch_date": "2022-01-05",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220205.002",
        "patch_date": "2022-02-05",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220305.012",
        "patch_date": "2022-03-01",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220405.003",
        "patch_date": "2022-04-05",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.002",
        "patch_date": "2022-05-05",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220605.009.A1",
        "patch_date": "2022-06-05",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003.A1",
        "patch_date": "2022-07-01",
        "model_firmware_codename": "sunfish",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TP1A.220624.014",
        "patch_date": "2022-08-05",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004",
        "patch_date": "2022-09-01",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.002",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TP1A.221105.002",
        "patch_date": "2022-11-05",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.011",
        "patch_date": "2022-12-01",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.221205.011.B1",
        "patch_date": "2022-12-01",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.001",
        "patch_date": "2023-01-05",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230105.001.B1",
        "patch_date": "2023-01-01",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.001.B2",
        "patch_date": "2023-02-01",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ1A.230205.002",
        "patch_date": "2023-02-05",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230305.008.C1",
        "patch_date": "2023-03-05",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003",
        "patch_date": "2023-04-05",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230405.003.B2",
        "patch_date": "2023-04-01",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ2A.230505.002",
        "patch_date": "2023-05-05",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230605.011",
        "patch_date": "2023-06-01",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230705.001",
        "patch_date": "2023-07-01",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.A2",
        "patch_date": "2023-08-05",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4a",
        "android_version": "13.0.0",
        "build_id": "TQ3A.230805.001.S1",
        "patch_date": "2023-11-01",
        "model_firmware_codename": "sunfish",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.007",
        "patch_date": "2019-10-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.011",
        "patch_date": "2019-10-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.011.C4",
        "patch_date": "2019-10-05",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.007.A3",
        "patch_date": "2019-11-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.014",
        "patch_date": "2019-11-05",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.014.C2",
        "patch_date": "2019-11-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ1B.191205.011",
        "patch_date": "2019-12-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ1B.191205.012.A1",
        "patch_date": "2019-12-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ1C.191205.016.A1",
        "patch_date": "2019-12-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ1B.200205.002",
        "patch_date": "2020-02-05",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ1C.200205.002",
        "patch_date": "2020-02-05",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ1D.200205.002",
        "patch_date": "2020-02-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200305.003",
        "patch_date": "2020-03-05",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200305.004.A1",
        "patch_date": "2020-03-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200405.005",
        "patch_date": "2020-04-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.A3",
        "patch_date": "2020-05-05",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.B2",
        "patch_date": "2020-05-05",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.001",
        "patch_date": "2020-06-01",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.002.A1",
        "patch_date": "2020-06-05",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200705.002",
        "patch_date": "2020-07-05",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200805.001",
        "patch_date": "2020-08-05",
        "model_firmware_codename": "coral",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.200720.009",
        "patch_date": "2020-09-01",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.004",
        "patch_date": "2020-10-05",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.201105.002",
        "patch_date": "2020-11-05",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.008",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.008.A1",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210105.003",
        "patch_date": "2021-01-01",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210205.004",
        "patch_date": "2021-02-01",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.006",
        "patch_date": "2021-03-01",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.005",
        "patch_date": "2021-04-05",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210505.002",
        "patch_date": "2021-05-05",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210605.005",
        "patch_date": "2021-06-01",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210705.001",
        "patch_date": "2021-07-05",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210805.001.A1",
        "patch_date": "2021-08-05",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210905.001",
        "patch_date": "2021-09-05",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.211001.001",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "coral",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.015",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A1",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002.A1",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.004",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.0.0",
        "build_id": "SQ1A.211205.008",
        "patch_date": "2021-12-01",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220105.002",
        "patch_date": "2022-01-05",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220205.002",
        "patch_date": "2022-02-05",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.1.0",
        "build_id": "SP2A.220305.012",
        "patch_date": "2022-03-05",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.1.0",
        "build_id": "SP2A.220405.003",
        "patch_date": "2022-04-01",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.002",
        "patch_date": "2022-05-01",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220605.009.A1",
        "patch_date": "2022-06-01",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003.A1",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "coral",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "13.0.0",
        "build_id": "TP1A.220624.014",
        "patch_date": "2022-08-05",
        "model_firmware_codename": "coral",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004",
        "patch_date": "2022-09-05",
        "model_firmware_codename": "coral",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.002",
        "patch_date": "2022-10-01",
        "model_firmware_codename": "coral",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4 XL",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.002.B2",
        "patch_date": "2023-02-01",
        "model_firmware_codename": "coral",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.007",
        "patch_date": "2019-10-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.011",
        "patch_date": "2019-10-05",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.011.C4",
        "patch_date": "2019-10-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.007.A3",
        "patch_date": "2019-11-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.014",
        "patch_date": "2019-11-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QD1A.190821.014.C2",
        "patch_date": "2019-11-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ1B.191205.011",
        "patch_date": "2019-12-05",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ1B.191205.012.A1",
        "patch_date": "2019-12-05",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ1C.191205.016.A1",
        "patch_date": "2019-12-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ1B.200205.002",
        "patch_date": "2020-02-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ1C.200205.002",
        "patch_date": "2020-02-05",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ1D.200205.002",
        "patch_date": "2020-02-05",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200305.003",
        "patch_date": "2020-03-05",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200305.004.A1",
        "patch_date": "2020-03-05",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200405.005",
        "patch_date": "2020-04-05",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.A3",
        "patch_date": "2020-05-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.B2",
        "patch_date": "2020-05-05",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.001",
        "patch_date": "2020-06-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.002.A1",
        "patch_date": "2020-06-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200705.002",
        "patch_date": "2020-07-01",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200805.001",
        "patch_date": "2020-08-05",
        "model_firmware_codename": "flame",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RP1A.200720.009",
        "patch_date": "2020-09-01",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.004",
        "patch_date": "2020-10-01",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RP1A.201105.002",
        "patch_date": "2020-11-01",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.008",
        "patch_date": "2020-12-01",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.008.A1",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210105.003",
        "patch_date": "2021-01-05",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210205.004",
        "patch_date": "2021-02-05",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.006",
        "patch_date": "2021-03-05",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.005",
        "patch_date": "2021-04-01",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210505.002",
        "patch_date": "2021-05-01",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210605.005",
        "patch_date": "2021-06-05",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210705.001",
        "patch_date": "2021-07-01",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210805.001.A1",
        "patch_date": "2021-08-05",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210905.001",
        "patch_date": "2021-09-01",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "11.0.0",
        "build_id": "RQ3A.211001.001",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "flame",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.015",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A1",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002.A1",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.004",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.0.0",
        "build_id": "SQ1A.211205.008",
        "patch_date": "2021-12-05",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220105.002",
        "patch_date": "2022-01-05",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220205.002",
        "patch_date": "2022-02-05",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.1.0",
        "build_id": "SP2A.220305.012",
        "patch_date": "2022-03-01",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.1.0",
        "build_id": "SP2A.220405.003",
        "patch_date": "2022-04-01",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.002",
        "patch_date": "2022-05-01",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220605.009.A1",
        "patch_date": "2022-06-05",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "12.1.0",
        "build_id": "SQ3A.220705.003.A1",
        "patch_date": "2022-07-05",
        "model_firmware_codename": "flame",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "13.0.0",
        "build_id": "TP1A.220624.014",
        "patch_date": "2022-08-05",
        "model_firmware_codename": "flame",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "13.0.0",
        "build_id": "TP1A.220905.004",
        "patch_date": "2022-09-01",
        "model_firmware_codename": "flame",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.002",
        "patch_date": "2022-10-05",
        "model_firmware_codename": "flame",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 4",
        "android_version": "13.0.0",
        "build_id": "TP1A.221005.002.B2",
        "patch_date": "2023-02-01",
        "model_firmware_codename": "flame",
        "api_level": "33",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "9.0.0",
        "build_id": "PQ3B.190605.006",
        "patch_date": "2019-06-05",
        "model_firmware_codename": "bonito",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "9.0.0",
        "build_id": "PQ3B.190705.003",
        "patch_date": "2019-07-01",
        "model_firmware_codename": "bonito",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "9.0.0",
        "build_id": "PQ3B.190801.002",
        "patch_date": "2019-08-01",
        "model_firmware_codename": "bonito",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.019",
        "patch_date": "2019-09-05",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020.C3",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.191005.007",
        "patch_date": "2019-10-01",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.191105.003",
        "patch_date": "2019-11-05",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QQ1A.191205.011",
        "patch_date": "2019-12-05",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QQ1A.200205.002",
        "patch_date": "2020-02-01",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200305.002",
        "patch_date": "2020-03-01",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200405.005",
        "patch_date": "2020-04-01",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.A3",
        "patch_date": "2020-05-05",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.B2",
        "patch_date": "2020-05-01",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.002",
        "patch_date": "2020-06-01",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.002.A1",
        "patch_date": "2020-06-05",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200705.002",
        "patch_date": "2020-07-01",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200805.001",
        "patch_date": "2020-08-01",
        "model_firmware_codename": "bonito",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.200720.009",
        "patch_date": "2020-09-01",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.004",
        "patch_date": "2020-10-01",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.201105.002",
        "patch_date": "2020-11-01",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.003",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210105.002",
        "patch_date": "2021-01-05",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210205.004",
        "patch_date": "2021-02-01",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.006",
        "patch_date": "2021-03-05",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.005",
        "patch_date": "2021-04-05",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210505.002",
        "patch_date": "2021-05-05",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210605.005",
        "patch_date": "2021-06-05",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210705.001",
        "patch_date": "2021-07-05",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210805.001.A1",
        "patch_date": "2021-08-01",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210905.001",
        "patch_date": "2021-09-01",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.211001.001",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "bonito",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.015",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A1",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002.A1",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.0.0",
        "build_id": "SQ1A.211205.008",
        "patch_date": "2021-12-01",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220105.002",
        "patch_date": "2022-01-01",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220205.002",
        "patch_date": "2022-02-01",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.1.0",
        "build_id": "SP2A.220305.012",
        "patch_date": "2022-03-05",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.1.0",
        "build_id": "SP2A.220405.003",
        "patch_date": "2022-04-05",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.002",
        "patch_date": "2022-05-05",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.006",
        "patch_date": "2022-05-01",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a XL",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.008",
        "patch_date": "2022-09-05",
        "model_firmware_codename": "bonito",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "9.0.0",
        "build_id": "PQ3B.190605.006",
        "patch_date": "2019-06-01",
        "model_firmware_codename": "sargo",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "9.0.0",
        "build_id": "PQ3B.190705.003",
        "patch_date": "2019-07-01",
        "model_firmware_codename": "sargo",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "9.0.0",
        "build_id": "PQ3B.190801.002",
        "patch_date": "2019-08-05",
        "model_firmware_codename": "sargo",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.019",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020.C3",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QP1A.191005.007",
        "patch_date": "2019-10-05",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QP1A.191105.003",
        "patch_date": "2019-11-05",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QQ1A.191205.011",
        "patch_date": "2019-12-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QQ1A.200205.002",
        "patch_date": "2020-02-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200305.002",
        "patch_date": "2020-03-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200405.005",
        "patch_date": "2020-04-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.A3",
        "patch_date": "2020-05-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.B2",
        "patch_date": "2020-05-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.002",
        "patch_date": "2020-06-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.002.A1",
        "patch_date": "2020-06-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200705.002",
        "patch_date": "2020-07-01",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200805.001",
        "patch_date": "2020-08-05",
        "model_firmware_codename": "sargo",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RP1A.200720.009",
        "patch_date": "2020-09-01",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.004",
        "patch_date": "2020-10-05",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RP1A.201105.002",
        "patch_date": "2020-11-01",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.003",
        "patch_date": "2020-12-01",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210105.002",
        "patch_date": "2021-01-01",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210205.004",
        "patch_date": "2021-02-05",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.006",
        "patch_date": "2021-03-01",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.005",
        "patch_date": "2021-04-05",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210505.002",
        "patch_date": "2021-05-05",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210605.005",
        "patch_date": "2021-06-01",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210705.001",
        "patch_date": "2021-07-05",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210805.001.A1",
        "patch_date": "2021-08-05",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210905.001",
        "patch_date": "2021-09-05",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "11.0.0",
        "build_id": "RQ3A.211001.001",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "sargo",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.015",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A1",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002",
        "patch_date": "2021-11-01",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.0.0",
        "build_id": "SP1A.211105.002.A1",
        "patch_date": "2021-11-05",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.0.0",
        "build_id": "SQ1A.211205.008",
        "patch_date": "2021-12-05",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220105.002",
        "patch_date": "2022-01-01",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.0.0",
        "build_id": "SQ1A.220205.002",
        "patch_date": "2022-02-01",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220305.012",
        "patch_date": "2022-03-05",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220405.003",
        "patch_date": "2022-04-01",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.002",
        "patch_date": "2022-05-01",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.006",
        "patch_date": "2022-05-05",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3a",
        "android_version": "12.1.0",
        "build_id": "SP2A.220505.008",
        "patch_date": "2022-09-01",
        "model_firmware_codename": "sargo",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PD1A.180720.030",
        "patch_date": "2018-09-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PD1A.180720.031",
        "patch_date": "2018-09-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181105.017.A1",
        "patch_date": "2018-11-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181205.006",
        "patch_date": "2018-12-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181205.006.A1",
        "patch_date": "2018-12-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ1A.190105.004",
        "patch_date": "2019-01-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190205.001",
        "patch_date": "2019-02-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190305.002",
        "patch_date": "2019-03-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190405.003",
        "patch_date": "2019-04-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190505.002",
        "patch_date": "2019-05-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190605.003",
        "patch_date": "2019-06-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190605.004.A1",
        "patch_date": "2019-06-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190705.003",
        "patch_date": "2019-07-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190801.002",
        "patch_date": "2019-08-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.019",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020.C3",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.191005.007",
        "patch_date": "2019-10-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.191105.003",
        "patch_date": "2019-11-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QQ1A.191205.008",
        "patch_date": "2019-12-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QQ1A.200205.002",
        "patch_date": "2020-02-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200305.002",
        "patch_date": "2020-03-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200405.005",
        "patch_date": "2020-04-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.A3",
        "patch_date": "2020-05-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.B2",
        "patch_date": "2020-05-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.001",
        "patch_date": "2020-06-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.002.A1",
        "patch_date": "2020-06-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200705.002",
        "patch_date": "2020-07-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200805.001",
        "patch_date": "2020-08-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.200720.009",
        "patch_date": "2020-09-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.004",
        "patch_date": "2020-10-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.201105.002",
        "patch_date": "2020-11-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.003",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.003.A1",
        "patch_date": "2020-12-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210105.003",
        "patch_date": "2021-01-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ1D.210105.003",
        "patch_date": "2021-01-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210205.004",
        "patch_date": "2021-02-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ1D.210205.004",
        "patch_date": "2021-02-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.006",
        "patch_date": "2021-03-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.005",
        "patch_date": "2021-04-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.006",
        "patch_date": "2021-04-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210505.002",
        "patch_date": "2021-05-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210605.005",
        "patch_date": "2021-06-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210705.001",
        "patch_date": "2021-07-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210805.001.A1",
        "patch_date": "2021-08-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210905.001",
        "patch_date": "2021-09-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "11.0.0",
        "build_id": "RQ3A.211001.001",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.015",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A1",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A2",
        "patch_date": "2022-01-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.B1",
        "patch_date": "2022-02-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.C1",
        "patch_date": "2022-02-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.B2",
        "patch_date": "2022-06-05",
        "model_firmware_codename": "crosshatch",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3 XL",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.C2",
        "patch_date": "2022-06-01",
        "model_firmware_codename": "crosshatch",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PD1A.180720.030",
        "patch_date": "2018-09-05",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PD1A.180720.031",
        "patch_date": "2018-09-05",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181105.017.A1",
        "patch_date": "2018-11-05",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181205.006",
        "patch_date": "2018-12-01",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181205.006.A1",
        "patch_date": "2018-12-05",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ1A.190105.004",
        "patch_date": "2019-01-01",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190205.001",
        "patch_date": "2019-02-05",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190305.002",
        "patch_date": "2019-03-05",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190405.003",
        "patch_date": "2019-04-05",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190505.002",
        "patch_date": "2019-05-05",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190605.003",
        "patch_date": "2019-06-05",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190605.004.A1",
        "patch_date": "2019-06-01",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190705.003",
        "patch_date": "2019-07-01",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190801.002",
        "patch_date": "2019-08-05",
        "model_firmware_codename": "blueline",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.019",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020.C3",
        "patch_date": "2019-09-05",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QP1A.191005.007",
        "patch_date": "2019-10-01",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QP1A.191105.003",
        "patch_date": "2019-11-05",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QQ1A.191205.008",
        "patch_date": "2019-12-01",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QQ1A.200205.002",
        "patch_date": "2020-02-01",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200305.002",
        "patch_date": "2020-03-01",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200405.005",
        "patch_date": "2020-04-05",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.A3",
        "patch_date": "2020-05-05",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.B2",
        "patch_date": "2020-05-05",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.001",
        "patch_date": "2020-06-05",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.002.A1",
        "patch_date": "2020-06-01",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200705.002",
        "patch_date": "2020-07-01",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200805.001",
        "patch_date": "2020-08-05",
        "model_firmware_codename": "blueline",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RP1A.200720.009",
        "patch_date": "2020-09-01",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.004",
        "patch_date": "2020-10-01",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RP1A.201105.002",
        "patch_date": "2020-11-01",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.003",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ1A.201205.003.A1",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210105.003",
        "patch_date": "2021-01-01",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ1D.210105.003",
        "patch_date": "2021-01-01",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ1A.210205.004",
        "patch_date": "2021-02-05",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ1D.210205.004",
        "patch_date": "2021-02-01",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210305.006",
        "patch_date": "2021-03-05",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.005",
        "patch_date": "2021-04-05",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210405.006",
        "patch_date": "2021-04-01",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ2A.210505.002",
        "patch_date": "2021-05-05",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210605.005",
        "patch_date": "2021-06-05",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210705.001",
        "patch_date": "2021-07-05",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210805.001.A1",
        "patch_date": "2021-08-01",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ3A.210905.001",
        "patch_date": "2021-09-01",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "11.0.0",
        "build_id": "RQ3A.211001.001",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "blueline",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.015",
        "patch_date": "2021-10-01",
        "model_firmware_codename": "blueline",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A1",
        "patch_date": "2021-10-05",
        "model_firmware_codename": "blueline",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.A2",
        "patch_date": "2022-01-05",
        "model_firmware_codename": "blueline",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.B1",
        "patch_date": "2022-02-01",
        "model_firmware_codename": "blueline",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.C1",
        "patch_date": "2022-02-05",
        "model_firmware_codename": "blueline",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.B2",
        "patch_date": "2022-06-01",
        "model_firmware_codename": "blueline",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 3",
        "android_version": "12.0.0",
        "build_id": "SP1A.210812.016.C2",
        "patch_date": "2022-06-05",
        "model_firmware_codename": "blueline",
        "api_level": "32",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.0.0",
        "build_id": "OPD1.170816.010",
        "patch_date": "2017-09-01",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.0.0",
        "build_id": "OPD1.170816.011",
        "patch_date": "2017-09-05",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.0.0",
        "build_id": "OPD1.170816.012",
        "patch_date": "2017-09-05",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.0.0",
        "build_id": "OPD3.170816.012",
        "patch_date": "2017-09-01",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.0.0",
        "build_id": "OPD1.170816.025",
        "patch_date": "2017-11-05",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.0.0",
        "build_id": "OPD3.170816.023",
        "patch_date": "2017-11-05",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.011",
        "patch_date": "2017-12-05",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.012",
        "patch_date": "2017-12-01",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.013",
        "patch_date": "2018-01-01",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.014",
        "patch_date": "2018-01-05",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.018",
        "patch_date": "2018-02-05",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.021",
        "patch_date": "2018-03-05",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.029",
        "patch_date": "2018-04-01",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.015.A1",
        "patch_date": "2018-04-05",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.029.B1",
        "patch_date": "2018-05-05",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.016.B1",
        "patch_date": "2018-05-01",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM2.171026.006.C1",
        "patch_date": "2018-06-01",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.E1",
        "patch_date": "2018-06-01",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM2.171026.006.H1",
        "patch_date": "2018-07-01",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.R1",
        "patch_date": "2018-07-01",
        "model_firmware_codename": "taimen",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PPR1.180610.009",
        "patch_date": "2018-08-01",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PPR1.180610.011",
        "patch_date": "2018-08-05",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PPR2.180905.005",
        "patch_date": "2018-09-05",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PPR2.181005.003",
        "patch_date": "2018-10-01",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181105.017.A1",
        "patch_date": "2018-11-01",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181205.002",
        "patch_date": "2018-12-05",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PQ1A.190105.004",
        "patch_date": "2019-01-05",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190205.002",
        "patch_date": "2019-02-01",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190305.002",
        "patch_date": "2019-03-05",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190405.003",
        "patch_date": "2019-04-01",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190505.001",
        "patch_date": "2019-05-05",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190605.003",
        "patch_date": "2019-06-05",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190705.001",
        "patch_date": "2019-07-05",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190801.002",
        "patch_date": "2019-08-05",
        "model_firmware_codename": "taimen",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.019",
        "patch_date": "2019-09-05",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.191005.007.A1",
        "patch_date": "2019-10-05",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.191105.004",
        "patch_date": "2019-11-01",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QQ1A.191205.008",
        "patch_date": "2019-12-01",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QQ1A.200205.002",
        "patch_date": "2020-02-01",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200305.002",
        "patch_date": "2020-03-05",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200405.005",
        "patch_date": "2020-04-05",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.A3",
        "patch_date": "2020-05-05",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.B3",
        "patch_date": "2020-05-01",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.001",
        "patch_date": "2020-06-05",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.002.A1",
        "patch_date": "2020-06-05",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200705.002",
        "patch_date": "2020-07-01",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200805.001",
        "patch_date": "2020-08-01",
        "model_firmware_codename": "taimen",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.200720.009",
        "patch_date": "2020-09-01",
        "model_firmware_codename": "taimen",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.004",
        "patch_date": "2020-10-05",
        "model_firmware_codename": "taimen",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2 XL",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.004.A1",
        "patch_date": "2020-12-01",
        "model_firmware_codename": "taimen",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.0.0",
        "build_id": "OPD1.170816.010",
        "patch_date": "2017-09-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.0.0",
        "build_id": "OPD1.170816.011",
        "patch_date": "2017-09-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.0.0",
        "build_id": "OPD1.170816.012",
        "patch_date": "2017-09-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.0.0",
        "build_id": "OPD3.170816.012",
        "patch_date": "2017-09-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.0.0",
        "build_id": "OPD1.170816.018",
        "patch_date": "2017-11-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.0.0",
        "build_id": "OPD2.170816.015",
        "patch_date": "2017-11-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.0.0",
        "build_id": "OPD3.170816.016",
        "patch_date": "2017-11-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.0.0",
        "build_id": "OPD1.170816.025",
        "patch_date": "2017-11-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.0.0",
        "build_id": "OPD3.170816.023",
        "patch_date": "2017-11-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.011",
        "patch_date": "2017-12-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.012",
        "patch_date": "2017-12-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.013",
        "patch_date": "2018-01-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.014",
        "patch_date": "2018-01-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.016",
        "patch_date": "2018-01-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.019",
        "patch_date": "2018-02-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.021",
        "patch_date": "2018-03-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.029",
        "patch_date": "2018-04-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.015.A1",
        "patch_date": "2018-04-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.029.B1",
        "patch_date": "2018-05-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.016.B1",
        "patch_date": "2018-05-05",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM2.171026.006.C1",
        "patch_date": "2018-06-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.E1",
        "patch_date": "2018-06-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM2.171026.006.G1",
        "patch_date": "2018-07-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.Q1",
        "patch_date": "2018-07-01",
        "model_firmware_codename": "walleye",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PPR1.180610.009",
        "patch_date": "2018-08-01",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PPR1.180610.011",
        "patch_date": "2018-08-05",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PPR2.180905.005",
        "patch_date": "2018-09-05",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PPR2.181005.003",
        "patch_date": "2018-10-05",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181105.017.A1",
        "patch_date": "2018-11-01",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181205.002",
        "patch_date": "2018-12-05",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PQ1A.190105.004",
        "patch_date": "2019-01-01",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190205.002",
        "patch_date": "2019-02-05",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190305.002",
        "patch_date": "2019-03-01",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190405.003",
        "patch_date": "2019-04-05",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190505.001",
        "patch_date": "2019-05-05",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190605.003",
        "patch_date": "2019-06-01",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190705.001",
        "patch_date": "2019-07-05",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190801.002",
        "patch_date": "2019-08-01",
        "model_firmware_codename": "walleye",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.019",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QP1A.191005.007.A1",
        "patch_date": "2019-10-01",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QP1A.191105.004",
        "patch_date": "2019-11-01",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QQ1A.191205.008",
        "patch_date": "2019-12-05",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QQ1A.200205.002",
        "patch_date": "2020-02-01",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200305.002",
        "patch_date": "2020-03-01",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200405.005",
        "patch_date": "2020-04-01",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.A3",
        "patch_date": "2020-05-01",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QQ2A.200501.001.B3",
        "patch_date": "2020-05-05",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.001",
        "patch_date": "2020-06-05",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200605.002.A1",
        "patch_date": "2020-06-01",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200705.002",
        "patch_date": "2020-07-01",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "10.0.0",
        "build_id": "QQ3A.200805.001",
        "patch_date": "2020-08-05",
        "model_firmware_codename": "walleye",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "11.0.0",
        "build_id": "RP1A.200720.009",
        "patch_date": "2020-09-01",
        "model_firmware_codename": "walleye",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.004",
        "patch_date": "2020-10-05",
        "model_firmware_codename": "walleye",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel 2",
        "android_version": "11.0.0",
        "build_id": "RP1A.201005.004.A1",
        "patch_date": "2020-12-05",
        "model_firmware_codename": "walleye",
        "api_level": "30",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.0.0",
        "build_id": "OPR6.170623.011",
        "patch_date": "2017-08-01",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.0.0",
        "build_id": "OPR6.170623.012",
        "patch_date": "2017-08-05",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.0.0",
        "build_id": "OPR1.170623.026",
        "patch_date": "2017-09-01",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.0.0",
        "build_id": "OPR3.170623.007",
        "patch_date": "2017-09-05",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.0.0",
        "build_id": "OPR1.170623.027",
        "patch_date": "2017-10-01",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.0.0",
        "build_id": "OPR3.170623.008",
        "patch_date": "2017-10-05",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.0.0",
        "build_id": "OPR1.170623.032",
        "patch_date": "2017-11-01",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.0.0",
        "build_id": "OPR3.170623.013",
        "patch_date": "2017-11-05",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.011",
        "patch_date": "2017-12-05",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.012",
        "patch_date": "2018-01-05",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.014",
        "patch_date": "2018-01-01",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.016",
        "patch_date": "2018-02-05",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.021",
        "patch_date": "2018-03-05",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.029",
        "patch_date": "2018-04-01",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.016.B1",
        "patch_date": "2018-05-05",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.D1",
        "patch_date": "2018-06-05",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.P1",
        "patch_date": "2018-07-01",
        "model_firmware_codename": "marlin",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PPR1.180610.009",
        "patch_date": "2018-08-05",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PPR1.180610.010",
        "patch_date": "2018-08-05",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PPR1.180905.003",
        "patch_date": "2018-09-05",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PPR2.180905.006",
        "patch_date": "2018-09-05",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PPR2.180905.006.A1",
        "patch_date": "2018-09-01",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PPR1.181005.003",
        "patch_date": "2018-10-01",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PPR2.181005.003",
        "patch_date": "2018-10-01",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PPR1.181005.003.A1",
        "patch_date": "2018-11-01",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PPR2.181005.003.A1",
        "patch_date": "2018-11-05",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181205.002.A1",
        "patch_date": "2018-12-01",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PQ1A.190105.004",
        "patch_date": "2019-01-05",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190205.003",
        "patch_date": "2019-02-05",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190305.002",
        "patch_date": "2019-03-01",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190405.003",
        "patch_date": "2019-04-05",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190505.001",
        "patch_date": "2019-05-01",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190605.003",
        "patch_date": "2019-06-01",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190705.001",
        "patch_date": "2019-07-05",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190801.002",
        "patch_date": "2019-08-01",
        "model_firmware_codename": "marlin",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.019",
        "patch_date": "2019-09-01",
        "model_firmware_codename": "marlin",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020",
        "patch_date": "2019-09-05",
        "model_firmware_codename": "marlin",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.191005.007.A1",
        "patch_date": "2019-10-05",
        "model_firmware_codename": "marlin",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel XL",
        "android_version": "10.0.0",
        "build_id": "QP1A.191005.007.A3",
        "patch_date": "2019-12-05",
        "model_firmware_codename": "marlin",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.0.0",
        "build_id": "OPR6.170623.011",
        "patch_date": "2017-08-05",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.0.0",
        "build_id": "OPR6.170623.012",
        "patch_date": "2017-08-05",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.0.0",
        "build_id": "OPR1.170623.026",
        "patch_date": "2017-09-01",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.0.0",
        "build_id": "OPR3.170623.007",
        "patch_date": "2017-09-01",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.0.0",
        "build_id": "OPR1.170623.027",
        "patch_date": "2017-10-01",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.0.0",
        "build_id": "OPR3.170623.008",
        "patch_date": "2017-10-05",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.0.0",
        "build_id": "OPR1.170623.032",
        "patch_date": "2017-11-05",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.0.0",
        "build_id": "OPR3.170623.013",
        "patch_date": "2017-11-01",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.011",
        "patch_date": "2017-12-01",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.012",
        "patch_date": "2018-01-01",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.014",
        "patch_date": "2018-01-01",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.016",
        "patch_date": "2018-02-05",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.021",
        "patch_date": "2018-03-01",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.029",
        "patch_date": "2018-04-05",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.016.B1",
        "patch_date": "2018-05-05",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.D1",
        "patch_date": "2018-06-05",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.P1",
        "patch_date": "2018-07-01",
        "model_firmware_codename": "sailfish",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PPR1.180610.009",
        "patch_date": "2018-08-05",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PPR1.180610.010",
        "patch_date": "2018-08-05",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PPR1.180905.003",
        "patch_date": "2018-09-01",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PPR2.180905.006",
        "patch_date": "2018-09-01",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PPR2.180905.006.A1",
        "patch_date": "2018-09-01",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PPR1.181005.003",
        "patch_date": "2018-10-01",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PPR2.181005.003",
        "patch_date": "2018-10-01",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PPR1.181005.003.A1",
        "patch_date": "2018-11-05",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PPR2.181005.003.A1",
        "patch_date": "2018-11-05",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PQ1A.181205.002.A1",
        "patch_date": "2018-12-05",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PQ1A.190105.004",
        "patch_date": "2019-01-01",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190205.003",
        "patch_date": "2019-02-01",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190305.002",
        "patch_date": "2019-03-01",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PQ2A.190405.003",
        "patch_date": "2019-04-01",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190505.001",
        "patch_date": "2019-05-01",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190605.003",
        "patch_date": "2019-06-05",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190705.001",
        "patch_date": "2019-07-05",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "9.0.0",
        "build_id": "PQ3A.190801.002",
        "patch_date": "2019-08-05",
        "model_firmware_codename": "sailfish",
        "api_level": "28",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.019",
        "patch_date": "2019-09-05",
        "model_firmware_codename": "sailfish",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "10.0.0",
        "build_id": "QP1A.190711.020",
        "patch_date": "2019-09-05",
        "model_firmware_codename": "sailfish",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "10.0.0",
        "build_id": "QP1A.191005.007.A1",
        "patch_date": "2019-10-01",
        "model_firmware_codename": "sailfish",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel",
        "android_version": "10.0.0",
        "build_id": "QP1A.191005.007.A3",
        "patch_date": "2019-12-01",
        "model_firmware_codename": "sailfish",
        "api_level": "29",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.0.0",
        "build_id": "OPR6.170623.010",
        "patch_date": "2017-08-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.0.0",
        "build_id": "OPR1.170623.026",
        "patch_date": "2017-09-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.0.0",
        "build_id": "OPR1.170623.027",
        "patch_date": "2017-10-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.0.0",
        "build_id": "OPR1.170623.032",
        "patch_date": "2017-11-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.011",
        "patch_date": "2017-12-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.015",
        "patch_date": "2018-01-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.016",
        "patch_date": "2018-02-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.022.A1",
        "patch_date": "2018-03-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.026",
        "patch_date": "2018-04-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.016.C1",
        "patch_date": "2018-05-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.D1",
        "patch_date": "2018-06-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.N1",
        "patch_date": "2018-07-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.Y1",
        "patch_date": "2018-08-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.021.Z1",
        "patch_date": "2018-09-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM8.181005.003",
        "patch_date": "2018-10-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM8.181105.002",
        "patch_date": "2018-11-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM8.181205.001",
        "patch_date": "2018-12-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM8.190105.002",
        "patch_date": "2019-01-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM8.190205.001",
        "patch_date": "2019-02-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM8.190305.001",
        "patch_date": "2019-03-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM8.190405.001",
        "patch_date": "2019-04-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM8.190505.001",
        "patch_date": "2019-05-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM8.190605.003",
        "patch_date": "2019-06-05",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Pixel C",
        "android_version": "8.1.0",
        "build_id": "OPM8.190605.005",
        "patch_date": "2019-06-01",
        "model_firmware_codename": "ryu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.0.0",
        "build_id": "OPR6.170623.013",
        "patch_date": "2017-08-05",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.0.0",
        "build_id": "OPR6.170623.019",
        "patch_date": "2017-09-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.0.0",
        "build_id": "OPR5.170623.007",
        "patch_date": "2017-10-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.0.0",
        "build_id": "OPR5.170623.011",
        "patch_date": "2017-11-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.0.0",
        "build_id": "OPR5.170623.014",
        "patch_date": "2017-12-05",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.011",
        "patch_date": "2017-12-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM3.171019.013",
        "patch_date": "2018-01-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM5.171019.014",
        "patch_date": "2018-01-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM3.171019.014",
        "patch_date": "2018-02-05",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM5.171019.015",
        "patch_date": "2018-02-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM3.171019.016",
        "patch_date": "2018-03-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM5.171019.017",
        "patch_date": "2018-03-05",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM3.171019.019",
        "patch_date": "2018-04-05",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM5.171019.019",
        "patch_date": "2018-04-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.029.A1",
        "patch_date": "2018-05-05",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM6.171019.030.B1",
        "patch_date": "2018-06-05",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM6.171019.030.E1",
        "patch_date": "2018-07-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM6.171019.030.K1",
        "patch_date": "2018-09-05",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM7.181005.003",
        "patch_date": "2018-10-01",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM7.181105.004",
        "patch_date": "2018-11-05",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 6P",
        "android_version": "8.1.0",
        "build_id": "OPM7.181205.001",
        "patch_date": "2018-12-05",
        "model_firmware_codename": "angler",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.0.0",
        "build_id": "OPR6.170623.013",
        "patch_date": "2017-08-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.0.0",
        "build_id": "OPR4.170623.006",
        "patch_date": "2017-09-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.0.0",
        "build_id": "OPR4.170623.020",
        "patch_date": "2017-12-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM1.171019.011",
        "patch_date": "2017-12-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM3.171019.013",
        "patch_date": "2018-01-01",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM5.171019.014",
        "patch_date": "2018-01-01",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM3.171019.014",
        "patch_date": "2018-02-01",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM5.171019.015",
        "patch_date": "2018-02-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM3.171019.016",
        "patch_date": "2018-03-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM5.171019.017",
        "patch_date": "2018-03-01",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM2.171019.029",
        "patch_date": "2018-04-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM4.171019.016.A1",
        "patch_date": "2018-05-01",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM6.171019.030.B1",
        "patch_date": "2018-06-01",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM6.171019.030.E1",
        "patch_date": "2018-07-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM6.171019.030.K1",
        "patch_date": "2018-09-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM7.181005.003",
        "patch_date": "2018-10-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM7.181105.004",
        "patch_date": "2018-11-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus 5X",
        "android_version": "8.1.0",
        "build_id": "OPM7.181205.001",
        "patch_date": "2018-12-05",
        "model_firmware_codename": "bullhead",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus Player",
        "android_version": "8.0.0",
        "build_id": "OPR6.170623.021",
        "patch_date": "2017-09-05",
        "model_firmware_codename": "fugu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
    {
        "model_name": "Nexus Player",
        "android_version": "8.0.0",
        "build_id": "OPR2.170623.027",
        "patch_date": "2017-11-01",
        "model_firmware_codename": "fugu",
        "api_level": "27",
        "manufecturer": "Google",
        "manufecturer_id": "google",
    },
]
